16.12. cdist-type__apt_update_index(7) — cdist 6.9.8 documentation

# 16.12. cdist-type__apt_update_index(7)

## 16.12.1. NAME

cdist-type__apt_update_index - Update apt's package index

## 16.12.2. DESCRIPTION

This cdist type runs apt-get update whenever any apt sources have changed.

## 16.12.3. REQUIRED PARAMETERS

None.

## 16.12.4. OPTIONAL PARAMETERS

None.

## 16.12.5. EXAMPLES

    __apt_update_index

## 16.12.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.12.7. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.